# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tasks_common.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x11task_status.proto\"\x80\x05\n\x07TaskRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cowner_pod_id\x18\x03 \x01(\t\x12\x17\n\x0fparent_task_ids\x18\x04 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x05 \x03(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x06 \x03(\t\x12\x14\n\x0cretry_of_ids\x18\x07 \x03(\t\x12;\n\x06status\x18\x08 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x16\n\x0estatus_message\x18\t \x01(\t\x12\x31\n\x07options\x18\n \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csubmitted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07pod_ttl\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06output\x18\x10 \x01(\x0b\x32).armonik.api.grpc.v1.tasks.TaskRaw.Output\x1a(\n\x06Output\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xba\x02\n\x0bTaskSummary\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"\xc2\x08\n\x10ListTasksRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x42\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x32.armonik.api.grpc.v1.tasks.ListTasksRequest.Filter\x12>\n\x04sort\x18\x04 \x01(\x0b\x32\x30.armonik.api.grpc.v1.tasks.ListTasksRequest.Sort\x12\x13\n\x0bwith_errors\x18\x05 \x01(\x08\x1a\x8a\x03\n\x06\x46ilter\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12;\n\x06status\x18\x02 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x31\n\rcreated_after\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rstarted_after\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0estarted_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65nded_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nded_before\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x9e\x01\n\x04Sort\x12G\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x38.armonik.api.grpc.v1.tasks.ListTasksRequest.OrderByField\x12M\n\tdirection\x18\x02 \x01(\x0e\x32:.armonik.api.grpc.v1.tasks.ListTasksRequest.OrderDirection\"\xdf\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x1a\n\x16ORDER_BY_FIELD_TASK_ID\x10\x01\x12\x1d\n\x19ORDER_BY_FIELD_SESSION_ID\x10\x02\x12\x19\n\x15ORDER_BY_FIELD_STATUS\x10\x03\x12\x1d\n\x19ORDER_BY_FIELD_CREATED_AT\x10\x04\x12\x1d\n\x19ORDER_BY_FIELD_STARTED_AT\x10\x05\x12\x1b\n\x17ORDER_BY_FIELD_ENDED_AT\x10\x06\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"z\n\x11ListTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x0eGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"C\n\x0fGetTaskResponse\x12\x30\n\x04task\x18\x01 \x01(\x0b\x32\".armonik.api.grpc.v1.tasks.TaskRaw\"&\n\x12\x43\x61ncelTasksRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"L\n\x13\x43\x61ncelTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\"&\n\x13GetResultIdsRequest\x12\x0f\n\x07task_id\x18\x01 \x03(\t\"\xa1\x01\n\x14GetResultIdsResponse\x12S\n\x0ctask_results\x18\x01 \x03(\x0b\x32=.armonik.api.grpc.v1.tasks.GetResultIdsResponse.MapTaskResult\x1a\x34\n\rMapTaskResult\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\nresult_ids\x18\x02 \x03(\tB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Tasksb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Tasks'
  _TASKRAW._serialized_start=117
  _TASKRAW._serialized_end=757
  _TASKRAW_OUTPUT._serialized_start=717
  _TASKRAW_OUTPUT._serialized_end=757
  _TASKSUMMARY._serialized_start=760
  _TASKSUMMARY._serialized_end=1074
  _LISTTASKSREQUEST._serialized_start=1077
  _LISTTASKSREQUEST._serialized_end=2167
  _LISTTASKSREQUEST_FILTER._serialized_start=1284
  _LISTTASKSREQUEST_FILTER._serialized_end=1678
  _LISTTASKSREQUEST_SORT._serialized_start=1681
  _LISTTASKSREQUEST_SORT._serialized_end=1839
  _LISTTASKSREQUEST_ORDERBYFIELD._serialized_start=1842
  _LISTTASKSREQUEST_ORDERBYFIELD._serialized_end=2065
  _LISTTASKSREQUEST_ORDERDIRECTION._serialized_start=2067
  _LISTTASKSREQUEST_ORDERDIRECTION._serialized_end=2167
  _LISTTASKSRESPONSE._serialized_start=2169
  _LISTTASKSRESPONSE._serialized_end=2291
  _GETTASKREQUEST._serialized_start=2293
  _GETTASKREQUEST._serialized_end=2326
  _GETTASKRESPONSE._serialized_start=2328
  _GETTASKRESPONSE._serialized_end=2395
  _CANCELTASKSREQUEST._serialized_start=2397
  _CANCELTASKSREQUEST._serialized_end=2435
  _CANCELTASKSRESPONSE._serialized_start=2437
  _CANCELTASKSRESPONSE._serialized_end=2513
  _GETRESULTIDSREQUEST._serialized_start=2515
  _GETRESULTIDSREQUEST._serialized_end=2553
  _GETRESULTIDSRESPONSE._serialized_start=2556
  _GETRESULTIDSRESPONSE._serialized_end=2717
  _GETRESULTIDSRESPONSE_MAPTASKRESULT._serialized_start=2665
  _GETRESULTIDSRESPONSE_MAPTASKRESULT._serialized_end=2717
# @@protoc_insertion_point(module_scope)
