# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: objects.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\robjects.proto\x12\x13\x61rmonik.api.grpc.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x11task_status.proto\"\x07\n\x05\x45mpty\"\xf3\x02\n\x0bTaskOptions\x12>\n\x07options\x18\x01 \x03(\x0b\x32-.armonik.api.grpc.v1.TaskOptions.OptionsEntry\x12/\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0bmax_retries\x18\x03 \x01(\x05\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12\x14\n\x0cpartition_id\x18\x05 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x06 \x01(\t\x12\x1b\n\x13\x61pplication_version\x18\x07 \x01(\t\x12\x1d\n\x15\x61pplication_namespace\x18\x08 \x01(\t\x12\x1b\n\x13\x61pplication_service\x18\t \x01(\t\x12\x13\n\x0b\x65ngine_type\x18\n \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x15\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\",\n\rConfiguration\x12\x1b\n\x13\x64\x61ta_chunk_max_size\x18\x01 \x01(\x05\"\x88\x01\n\x06Output\x12(\n\x02ok\x18\x02 \x01(\x0b\x32\x1a.armonik.api.grpc.v1.EmptyH\x00\x12\x32\n\x05\x65rror\x18\x03 \x01(\x0b\x32!.armonik.api.grpc.v1.Output.ErrorH\x00\x1a\x18\n\x05\x45rror\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x06\n\x04type\"W\n\x0bTaskRequest\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"C\n\x13InitKeyedDataStream\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x15\n\x0blast_result\x18\x02 \x01(\x08H\x00\x42\x06\n\x04type\"<\n\tDataChunk\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\x17\n\rdata_complete\x18\x02 \x01(\x08H\x00\x42\x06\n\x04type\"L\n\x11TaskRequestHeader\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\"h\n\x0fInitTaskRequest\x12\x38\n\x06header\x18\x01 \x01(\x0b\x32&.armonik.api.grpc.v1.TaskRequestHeaderH\x00\x12\x13\n\tlast_task\x18\x02 \x01(\x08H\x00\x42\x06\n\x04type\"\'\n\x06TaskId\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\"\x1e\n\nTaskIdList\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"Y\n\x0bStatusCount\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"9\n\x05\x43ount\x12\x30\n\x06values\x18\x01 \x03(\x0b\x32 .armonik.api.grpc.v1.StatusCount\"3\n\rResultRequest\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\t\"5\n\x11TaskOutputRequest\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\"Y\n\x05\x45rror\x12@\n\x0btask_status\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\"H\n\tTaskError\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12*\n\x06\x65rrors\x18\x02 \x03(\x0b\x32\x1a.armonik.api.grpc.v1.Error\"9\n\x08TaskList\x12-\n\x08task_ids\x18\x01 \x03(\x0b\x32\x1b.armonik.api.grpc.v1.TaskId\"}\n\x10TaskIdWithStatus\x12,\n\x07task_id\x18\x01 \x01(\x0b\x32\x1b.armonik.api.grpc.v1.TaskId\x12;\n\x06status\x18\x02 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatusB\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'objects_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _TASKOPTIONS_OPTIONSENTRY._options = None
  _TASKOPTIONS_OPTIONSENTRY._serialized_options = b'8\001'
  _EMPTY._serialized_start=89
  _EMPTY._serialized_end=96
  _TASKOPTIONS._serialized_start=99
  _TASKOPTIONS._serialized_end=470
  _TASKOPTIONS_OPTIONSENTRY._serialized_start=424
  _TASKOPTIONS_OPTIONSENTRY._serialized_end=470
  _SESSION._serialized_start=472
  _SESSION._serialized_end=493
  _CONFIGURATION._serialized_start=495
  _CONFIGURATION._serialized_end=539
  _OUTPUT._serialized_start=542
  _OUTPUT._serialized_end=678
  _OUTPUT_ERROR._serialized_start=646
  _OUTPUT_ERROR._serialized_end=670
  _TASKREQUEST._serialized_start=680
  _TASKREQUEST._serialized_end=767
  _INITKEYEDDATASTREAM._serialized_start=769
  _INITKEYEDDATASTREAM._serialized_end=836
  _DATACHUNK._serialized_start=838
  _DATACHUNK._serialized_end=898
  _TASKREQUESTHEADER._serialized_start=900
  _TASKREQUESTHEADER._serialized_end=976
  _INITTASKREQUEST._serialized_start=978
  _INITTASKREQUEST._serialized_end=1082
  _TASKID._serialized_start=1084
  _TASKID._serialized_end=1123
  _TASKIDLIST._serialized_start=1125
  _TASKIDLIST._serialized_end=1155
  _STATUSCOUNT._serialized_start=1157
  _STATUSCOUNT._serialized_end=1246
  _COUNT._serialized_start=1248
  _COUNT._serialized_end=1305
  _RESULTREQUEST._serialized_start=1307
  _RESULTREQUEST._serialized_end=1358
  _TASKOUTPUTREQUEST._serialized_start=1360
  _TASKOUTPUTREQUEST._serialized_end=1413
  _ERROR._serialized_start=1415
  _ERROR._serialized_end=1504
  _TASKERROR._serialized_start=1506
  _TASKERROR._serialized_end=1578
  _TASKLIST._serialized_start=1580
  _TASKLIST._serialized_end=1637
  _TASKIDWITHSTATUS._serialized_start=1639
  _TASKIDWITHSTATUS._serialized_end=1764
# @@protoc_insertion_point(module_scope)
