# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: task_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11task_status.proto\x12\x1f\x61rmonik.api.grpc.v1.task_status*\xb3\x02\n\nTaskStatus\x12\x1b\n\x17TASK_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14TASK_STATUS_CREATING\x10\x01\x12\x19\n\x15TASK_STATUS_SUBMITTED\x10\x02\x12\x1a\n\x16TASK_STATUS_DISPATCHED\x10\x03\x12\x19\n\x15TASK_STATUS_COMPLETED\x10\x04\x12\x15\n\x11TASK_STATUS_ERROR\x10\x05\x12\x17\n\x13TASK_STATUS_TIMEOUT\x10\x06\x12\x1a\n\x16TASK_STATUS_CANCELLING\x10\x07\x12\x19\n\x15TASK_STATUS_CANCELLED\x10\x08\x12\x1a\n\x16TASK_STATUS_PROCESSING\x10\t\x12\x19\n\x15TASK_STATUS_PROCESSED\x10\nB\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'task_status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _TASKSTATUS._serialized_start=55
  _TASKSTATUS._serialized_end=362
# @@protoc_insertion_point(module_scope)
