# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import objects_pb2 as objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_common.proto\x12\x19\x61rmonik.api.grpc.v1.agent\x1a\robjects.proto\"\xc4\x02\n\x11\x43reateTaskRequest\x12P\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x38.armonik.api.grpc.v1.agent.CreateTaskRequest.InitRequestH\x00\x12\x39\n\tinit_task\x18\x02 \x01(\x0b\x32$.armonik.api.grpc.v1.InitTaskRequestH\x00\x12\x36\n\x0ctask_payload\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1a\x45\n\x0bInitRequest\x12\x36\n\x0ctask_options\x18\x01 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptionsB\x06\n\x04type\"\xe3\x03\n\x0f\x43reateTaskReply\x12]\n\x14\x63reation_status_list\x18\x01 \x01(\x0b\x32=.armonik.api.grpc.v1.agent.CreateTaskReply.CreationStatusListH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1aT\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpected_output_keys\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x1au\n\x0e\x43reationStatus\x12H\n\ttask_info\x18\x01 \x01(\x0b\x32\x33.armonik.api.grpc.v1.agent.CreateTaskReply.TaskInfoH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x42\x08\n\x06Status\x1aj\n\x12\x43reationStatusList\x12T\n\x11\x63reation_statuses\x18\x01 \x03(\x0b\x32\x39.armonik.api.grpc.v1.agent.CreateTaskReply.CreationStatusB\n\n\x08Response\"7\n\x0b\x44\x61taRequest\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x90\x02\n\tDataReply\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12\x39\n\x04init\x18\x02 \x01(\x0b\x32).armonik.api.grpc.v1.agent.DataReply.InitH\x00\x12.\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x0f\n\x05\x65rror\x18\x04 \x01(\tH\x00\x1a\x62\n\x04Init\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x0f\n\x05\x65rror\x18\x03 \x01(\tH\x00\x42\x0c\n\nhas_resultB\x06\n\x04type\"\x97\x01\n\x06Result\x12\x38\n\x04init\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.InitKeyedDataStreamH\x00\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\tB\x06\n\x04type\"m\n\x0bResultReply\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\t\x12(\n\x02Ok\x18\x01 \x01(\x0b\x32\x1a.armonik.api.grpc.v1.EmptyH\x00\x12\x0f\n\x05\x45rror\x18\x02 \x01(\tH\x00\x42\x06\n\x04typeB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Agentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Agent'
  _CREATETASKREQUEST._serialized_start=65
  _CREATETASKREQUEST._serialized_end=389
  _CREATETASKREQUEST_INITREQUEST._serialized_start=312
  _CREATETASKREQUEST_INITREQUEST._serialized_end=381
  _CREATETASKREPLY._serialized_start=392
  _CREATETASKREPLY._serialized_end=875
  _CREATETASKREPLY_TASKINFO._serialized_start=552
  _CREATETASKREPLY_TASKINFO._serialized_end=636
  _CREATETASKREPLY_CREATIONSTATUS._serialized_start=638
  _CREATETASKREPLY_CREATIONSTATUS._serialized_end=755
  _CREATETASKREPLY_CREATIONSTATUSLIST._serialized_start=757
  _CREATETASKREPLY_CREATIONSTATUSLIST._serialized_end=863
  _DATAREQUEST._serialized_start=877
  _DATAREQUEST._serialized_end=932
  _DATAREPLY._serialized_start=935
  _DATAREPLY._serialized_end=1207
  _DATAREPLY_INIT._serialized_start=1101
  _DATAREPLY_INIT._serialized_end=1199
  _RESULT._serialized_start=1210
  _RESULT._serialized_end=1361
  _RESULTREPLY._serialized_start=1363
  _RESULTREPLY._serialized_end=1472
# @@protoc_insertion_point(module_scope)
